==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/qasmixer/src/mwdg/mixer_sliders_proxy_slider.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "qsnd/mixer_simple_elem.hpp"
#include "wdg/pad_proxy_slider.hpp"
#include <QString>

namespace MWdg
{

/// @brief Mixer_Sliders_Proxy_Slider
///
class Mixer_Sliders_Proxy_Slider : public ::Wdg::Pad_Proxy_Slider
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Mixer_Sliders_Proxy_Slider ();

  ~Mixer_Sliders_Proxy_Slider ();

  // -- Mixer simple elem

  ::QSnd::Mixer_Simple_Elem *
  mixer_simple_elem () const
  {
    return _mixer_simple_elem;
  }

  void
  set_mixer_simple_elem ( ::QSnd::Mixer_Simple_Elem * selem_n );

  // -- Snd dir

  unsigned char
  snd_dir () const
  {
    return _snd_dir;
  }

  void
  set_snd_dir ( unsigned char dir_n );

  // -- Channel idx

  unsigned int
  channel_idx () const
  {
    return _channel_idx;
  }

  void
  set_channel_idx ( unsigned int idx_n );

  // -- Is joined flag

  bool
  is_joined () const
  {
    return _is_joined;
  }

  void
  set_is_joined ( bool flag_n );

  // -- Volume

  long
  volume_max () const
  {
    return _volume_max;
  }

  long
  volume_min () const
  {
    return _volume_min;
  }

  long
  volume_value () const
  {
    return _volume_val;
  }

  int
  volume_permille () const;

  // -- Decibel

  bool
  has_dB () const
  {
    if ( mixer_simple_elem () == nullptr ) {
      return false;
    }
    return mixer_simple_elem ()->has_dB ( snd_dir () );
  }

  long
  ask_dB_vol ( long dB_value_n, int dir_n = -1 )
  {
    return mixer_simple_elem ()->ask_dB_vol ( snd_dir (), dB_value_n, dir_n );
  }

  long
  ask_dB_vol_nearest ( long dB_value_n )
  {
    return mixer_simple_elem ()->ask_dB_vol_nearest ( snd_dir (), dB_value_n );
  }

  long
  ask_vol_dB ( long volume_n )
  {
    return mixer_simple_elem ()->ask_vol_dB ( snd_dir (), volume_n );
  }

  long
  dB_value () const
  {
    return _dB_val;
  }

  void
  set_dB_value ( long dB_val_n );

  long
  dB_max () const
  {
    return mixer_simple_elem ()->dB_max ( snd_dir () );
  }

  long
  dB_min () const
  {
    return mixer_simple_elem ()->dB_min ( snd_dir () );
  }

  bool
  eventFilter ( QObject * obj_n, QEvent * event_n );

  // -- Public signals

  Q_SIGNAL
  void
  sig_dB_value_changed ( long dB_value_n );

  // -- Public slots

  Q_SLOT
  void
  set_volume_value ( long value_n );

  Q_SLOT
  void
  update_value_from_source ();

  // Protected methods
  protected:
  void
  update_limits ();

  void
  dB_value_changed ();

  void
  volume_value_changed ();

  void
  slider_index_changed ();

  // Private attributes
  private:
  ::QSnd::Mixer_Simple_Elem * _mixer_simple_elem;

  long _volume_val;
  long _volume_min;
  long _volume_max;
  long _dB_val;

  unsigned int _channel_idx;
  unsigned char _snd_dir;

  bool _is_joined;
  bool _alsa_updating;
};

} // namespace MWdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/qasmixer/src/mwdg/mixer_sliders_proxy_slider.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "qsnd/mixer/elem.hpp"
#include "wdg/pad_proxy_slider.hpp"
#include <QString>

namespace MWdg
{

/// @brief Mixer_Sliders_Proxy_Slider
///
class Mixer_Sliders_Proxy_Slider : public Wdg::Pad_Proxy_Slider
{
  Q_OBJECT

  public:
  // -- Construction

  Mixer_Sliders_Proxy_Slider ();

  ~Mixer_Sliders_Proxy_Slider ();

  // -- Mixer simple elem

  QSnd::Mixer::Elem *
  mixer_simple_elem () const
  {
    return _mixer_simple_elem;
  }

  void
  set_mixer_simple_elem ( QSnd::Mixer::Elem * selem_n );

  // -- Snd dir

  unsigned char
  snd_dir () const
  {
    return _snd_dir;
  }

  void
  set_snd_dir ( unsigned char dir_n );

  // -- Channel idx

  unsigned int
  channel_idx () const
  {
    return _channel_idx;
  }

  void
  set_channel_idx ( unsigned int idx_n );

  // -- Is joined flag

  bool
  is_joined () const
  {
    return _is_joined;
  }

  void
  set_is_joined ( bool flag_n );

  // -- Volume

  long
  volume_max () const
  {
    return _volume_max;
  }

  long
  volume_min () const
  {
    return _volume_min;
  }

  long
  volume_value () const
  {
    return _volume_val;
  }

  int
  volume_permille () const;

  // -- Decibel

  bool
  has_dB () const
  {
    if ( mixer_simple_elem () == nullptr ) {
      return false;
    }
    return mixer_simple_elem ()->has_dB ( snd_dir () );
  }

  long
  ask_dB_vol ( long dB_value_n, int dir_n = -1 )
  {
    return mixer_simple_elem ()->ask_dB_vol ( snd_dir (), dB_value_n, dir_n );
  }

  long
  ask_dB_vol_nearest ( long dB_value_n )
  {
    return mixer_simple_elem ()->ask_dB_vol_nearest ( snd_dir (), dB_value_n );
  }

  long
  ask_vol_dB ( long volume_n )
  {
    return mixer_simple_elem ()->ask_vol_dB ( snd_dir (), volume_n );
  }

  long
  dB_value () const
  {
    return _dB_val;
  }

  void
  set_dB_value ( long dB_val_n );

  long
  dB_max () const
  {
    return mixer_simple_elem ()->dB_max ( snd_dir () );
  }

  long
  dB_min () const
  {
    return mixer_simple_elem ()->dB_min ( snd_dir () );
  }

  bool
  eventFilter ( QObject * obj_n, QEvent * event_n );

  // -- Public signals

  Q_SIGNAL
  void
  sig_dB_value_changed ( long dB_value_n );

  // -- Public slots

  Q_SLOT
  void
  set_volume_value ( long value_n );

  Q_SLOT
  void
  update_value_from_source ();

  protected:
  // -- Protected methods

  void
  update_limits ();

  void
  dB_value_changed ();

  void
  volume_value_changed ();

  void
  slider_index_changed ();

  private:
  // -- Attributes
  QSnd::Mixer::Elem * _mixer_simple_elem;

  long _volume_val;
  long _volume_min;
  long _volume_max;
  long _dB_val;

  unsigned int _channel_idx;
  unsigned char _snd_dir;

  bool _is_joined;
  bool _alsa_updating;
};

} // namespace MWdg
